#ifndef AM128CTL_H
#define AM128CTL_H
/***************************************************************************
 * INCLUDEFILE   : AM128CTL.H
 * to MODULE     : 
 * Author        : RAV
 * Creation Date : 23.11.2006
 *
 * Copyright     : (c) SPECTRO SYSTEME GmbH 2006
 *
 *-------------------------------------------------------------------------*
 * Project       : 
 *
 * Version       : 1.00
 *
 * Description   : SFR control macros
 *
 * Specials      : 
 * System        : Atmel ATmega128
 *
 *-------------------------------------------------------------------------*
 *
 * Name:      Vers.  Date:       History of Changes :
 *
 * RAV        1.00   23.11.2006  First Implementation
 *
 ***************************************************************************/

/** External includes ******************************************************/
#include <AVR/IO.H> 
//#include <AVR/INTERRUPT.H>

/** Interrupt macros *******************************************************/

#define ENABLE_INTERRUPTS              {} /*sei()*/
#define DISABLE_INTERRUPTS             {} /*cli()*/
#define ENABLE_SIO_0_REC_INT           {UCSR0B |= 0x80; SREG |= 0x80;} /* RX Complete */
#define DISABLE_SIO_0_REC_INT          UCSR0B &= ~0x80
#define ENABLE_SIO_0_TRM_INT           {UCSR0B |= 0x40; SREG |= 0x80;} /* TX Complete */
#define DISABLE_SIO_0_TRM_INT          UCSR0B &= ~0x40
#define ENABLE_SIO_0_DRE_INT           {UCSR0B |= 0x20; SREG |= 0x80;} /* Data Regsiter Empty */
#define DISABLE_SIO_0_DRE_INT          UCSR0B &= ~0x20

/** USART 0 macros *********************************************************/

#define SEL_SIO_0_ASYNC_MODE           UCSR0C &= ~0x40
#define SEL_SIO_0_SYNC_MODE            UCSR0C |=  0x40
#define SEL_SIO_0_DEF_SPEED            UCSR0A &= ~0x02
#define SEL_SIO_0_X2_SPEED             UCSR0A |=  0x02
#define SET_SIO_0_BR_REG(x)            {UBRR0L = (unsigned char)((x) & 0xFF); UBRR0H = (unsigned char)((x) >> 8);}
#define SEL_SIO_0_7_BIT_DATA           {UCSR0B &= ~0x04; UCSR0C |= 0x04; UCSR0C &= ~0x02;}
#define SEL_SIO_0_8_BIT_DATA           {UCSR0B &= ~0x04; UCSR0C |= 0x06;}
#define SEL_SIO_0_NO_PARITY            UCSR0C &= ~0x30
#define SEL_SIO_0_EVEN_PARITY          {UCSR0C &= ~0x30; UCSR0C |= 0x20;}
#define SEL_SIO_0_ODD_PARITY           UCSR0C |=  0x30
#define SEL_SIO_0_1_STOPBIT            UCSR0C &= ~0x08
#define SEL_SIO_0_2_STOPBITS           UCSR0C |=  0x08

#define TRANSMIT_SIO_0_DATA(x)         UDR0 = (x)
#define READ_SIO_0_ERRORS(x)           (x) = UCSR0A & 0x1C
#define READ_SIO_0_DATA(x)             (x) = UDR0
#define SIO_0_TRM_REG_EMPTY            ((UCSR0A & 0x20) != 0x00)

/** PORT D macros **********************************************************/

#define SEL_PD0_OUTPUT                 {PORTD |= 0x01; DDRD |=  0x01;}
#define SEL_PD0_INPUT                  {PORTD |= 0x01; DDRD &= ~0x01;}
#define SEL_PD1_OUTPUT                 {PORTD |= 0x02; DDRD |=  0x02;}
#define SEL_PD1_INPUT                  {PORTD |= 0x02; DDRD &= ~0x02;}
#define SEL_PD2_OUTPUT                 {PORTD |= 0x04; DDRD |=  0x04;}
#define SEL_PD2_INPUT                  {PORTD |= 0x04; DDRD &= ~0x04;}
#define SEL_PD3_OUTPUT                 {PORTD |= 0x08; DDRD |=  0x08;}
#define SEL_PD3_INPUT                  {PORTD |= 0x08; DDRD &= ~0x08;}
#define SEL_PD4_OUTPUT                 {PORTD |= 0x10; DDRD |=  0x10;}
#define SEL_PD4_INPUT                  {PORTD |= 0x10; DDRD &= ~0x10;}
#define SEL_PD5_OUTPUT                 {PORTD |= 0x20; DDRD |=  0x20;}
#define SEL_PD5_INPUT                  {PORTD |= 0x20; DDRD &= ~0x20;}
#define SEL_PD6_OUTPUT                 {PORTD |= 0x40; DDRD |=  0x40;}
#define SEL_PD6_INPUT                  {PORTD |= 0x40; DDRD &= ~0x40;}
#define SEL_PD7_OUTPUT                 {PORTD |= 0x80; DDRD |=  0x80;}
#define SEL_PD7_INPUT                  {PORTD |= 0x80; DDRD &= ~0x80;}


/** PORT E macros **********************************************************/

#define SEL_PE0_RXD0                   {PORTE |= 0x01; UCSR0B |= 0x10;}
#define SEL_PE0_IO_PORT                UCSR0B &= ~0x10
#define SEL_PE0_OUTPUT                 {PORTE |= 0x01; DDRE |=  0x01;}
#define SEL_PE0_INPUT                  {PORTE |= 0x01; DDRE &= ~0x01;}

#define SEL_PE1_TXD0                   UCSR0B |=  0x08
#define SEL_PE1_IO_PORT                UCSR0B &= ~0x08
#define SEL_PE1_OUTPUT                 {PORTE |= 0x02; DDRE |=  0x02;}
#define SEL_PE1_INPUT                  {PORTE |= 0x02; DDRE &= ~0x02;}

#define SEL_PE2_OUTPUT                 {PORTE |= 0x04; DDRE |=  0x04;}
#define SEL_PE2_INPUT                  {PORTE |= 0x04; DDRE &= ~0x04;}


#endif


